#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-metrics
version:              0.3.0
visibility:           public
id:                   text-metrics-0.3.0-KX5t5hBXlFc50u8T4lDfZp
key:                  text-metrics-0.3.0-KX5t5hBXlFc50u8T4lDfZp
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/text-metrics
synopsis:             Calculate various string metrics efficiently
description:          Calculate various string metrics efficiently.
category:             Text, Algorithms
abi:                  d596d84164343918786c3f854a5713b7
exposed:              True
exposed-modules:      Data.Text.Metrics
import-dirs:          /usr/lib/ghc-8.10.5/site-local/text-metrics-0.3.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/text-metrics-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/text-metrics-0.3.0
hs-libraries:         HStext-metrics-0.3.0-KX5t5hBXlFc50u8T4lDfZp
depends:
    base-4.14.2.0 containers-0.6.4.1 text-1.2.4.1
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock

haddock-html:         /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

